/* Gnome Scan - Scan as easy as you print
 * Copyright © 2007  Étienne Bersac <bersace03@laposte.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR  A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with main.c; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */
 
#ifndef _GNOME_SCAN_INIT_H
#define _GNOME_SCAN_INIT_H

#include <glib-object.h>

/**
 * Stock item for scan action.
 **/
#define	GS_STOCK_SCAN	"scan"

G_BEGIN_DECLS

void	gnome_scan_init (gint *argc, gchar ***argv);
void	gnome_scan_exit (void);

G_END_DECLS

#endif /* _GNOME_SCAN_INIT_H */
